@@ -15,14 +15,7 @@ def manage(path):
 def wsgi(path):
     _setup(path=path)
     from django.core.wsgi import get_wsgi_application
-    from django.conf import settings
-    from dj_static import Cling, MediaCling
     app = get_wsgi_application()
-    if settings.ENABLE_SYNCING:
-        if not settings.STATIC_URL_IS_ON_OTHER_DOMAIN:
-            app = Cling(app)
-        if not settings.MEDIA_URL_IS_ON_OTHER_DOMAIN:
-            app = MediaCling(app)
     return app
 
 
